summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvastext_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvastext_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvastext_imp.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/kjsembed/qtbindings/qcanvastext_imp.cpp b/kjsembed/qtbindings/qcanvastext_imp.cpp
index 84548eea..44db9795 100644
--- a/kjsembed/qtbindings/qcanvastext_imp.cpp
+++ b/kjsembed/qtbindings/qcanvastext_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvastext_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -80,7 +80,7 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -93,25 +93,25 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasText pointer from an Object.
*/
-QCanvasText *QCanvasTextImp::toQCanvasText( KJS::Object &self )
+TQCanvasText *QCanvasTextImp::toQCanvasText( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasText *>( obj );
+ return dynamic_cast<TQCanvasText *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasText" )
+ if ( op->typeName() != "TQCanvasText" )
return 0;
- return op->toNative<QCanvasText>();
+ return op->toNative<TQCanvasText>();
}
/**
@@ -137,7 +137,7 @@ KJS::Object QCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &ar
break;
}
- QString msg = i18n("QCanvasTextCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasTextCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -145,15 +145,15 @@ KJS::Object QCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object QCanvasTextImp::QCanvasText_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the QCanvasText object
+ // We should now create an instance of the TQCanvasText object
- QCanvasText *ret = new QCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0 );
@@ -163,17 +163,17 @@ KJS::Object QCanvasTextImp::QCanvasText_1( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasTextImp::QCanvasText_2( KJS::ExecState *exec, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- QCanvas * arg1; // Dummy
+ TQCanvas * arg1; // Dummy
- // We should now create an instance of the QCanvasText object
+ // We should now create an instance of the TQCanvasText object
- QCanvasText *ret = new QCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0,
arg1 );
@@ -184,22 +184,22 @@ KJS::Object QCanvasTextImp::QCanvasText_2( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasTextImp::QCanvasText_3( KJS::ExecState *exec, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
// Unsupported parameter QFont
return KJS::Object();
- QFont arg1; // Dummy
+ TQFont arg1; // Dummy
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- QCanvas * arg2; // Dummy
+ TQCanvas * arg2; // Dummy
- // We should now create an instance of the QCanvasText object
+ // We should now create an instance of the TQCanvasText object
- QCanvasText *ret = new QCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0,
arg1,
@@ -266,7 +266,7 @@ KJS::Value QCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- QString msg = i18n( "QCanvasTextImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasTextImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -274,7 +274,7 @@ KJS::Value QCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const
KJS::Value QCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
instance->setText(
arg0 );
@@ -285,7 +285,7 @@ KJS::Value QCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QFont arg0 = extractQFont(exec, args, 0);
+ TQFont arg0 = extractQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -296,7 +296,7 @@ KJS::Value QCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QColor arg0 = extractQColor(exec, args, 0);
+ TQColor arg0 = extractQColor(exec, args, 0);
instance->setColor(
arg0 );
@@ -307,7 +307,7 @@ KJS::Value QCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QCanvasTextImp::text_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->text( );
return KJS::String( ret );
@@ -365,7 +365,7 @@ KJS::Value QCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &o
KJS::Value QCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QRect ret;
+ TQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
@@ -375,10 +375,10 @@ KJS::Value QCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &o
KJS::Value QCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QCanvasItem *
return KJS::Value();
- const QCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -93,25 +93,25 @@ void QCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasText pointer from an Object.
+ * Extract a TQCanvasText pointer from an Object.
*/
@@ -145,15 +145,15 @@ KJS::Object QCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object QCanvasTextImp::QCanvasText_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
@@ -375,10 +375,10 @@ KJS::Value QCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &o
KJS::Value QCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();